package Foorum::View::JSON;

use strict;
use Foorum::Version; our $VERSION = $Foorum::VERSION;
use base 'Catalyst::View::JSON';

1;
__END__

=pod

=head1 NAME

Foorum::View::JSON - JSON for Foorum

=head1 SEE ALSO

L<Catalyst::View::JSON>

=head1 AUTHOR

Fayland Lam <fayland at gmail.com>

=cut
